Index: compat/mac/mach-o/getsect.cc |
diff --git a/compat/mac/mach-o/getsect.cc b/compat/mac/mach-o/getsect.cc |
index 5401b39ba1a6f7bef75740e0fe0abdbd28190f28..b713180f39132c98833795af94c9ba9af52ca064 100644 |
--- a/compat/mac/mach-o/getsect.cc |
+++ b/compat/mac/mach-o/getsect.cc |
@@ -37,22 +37,22 @@ namespace { |
// getsectbyname() function. getsectbyname() is always present in libmacho. |
// getsectiondata() and getsegmentdata() are not always present, but when they |
// are, they’re in the same library as getsectbyname(). If the library cannot |
// be found or a handle to it cannot be returned, returns NULL. |
void* SystemLibMachOHandle() { |
Dl_info info; |
if (!dladdr(reinterpret_cast<void*>(getsectbyname), &info)) { |
- return NULL; |
+ return nullptr; |
} |
return dlopen(info.dli_fname, RTLD_LAZY | RTLD_LOCAL); |
} |
// Returns a function pointer to a function in libmacho based on a lookup of |
// that function by symbol name. Returns NULL if libmacho cannot be found or |
// opened, or if the named symbol cannot be found in libmacho. |
void* LookUpSystemLibMachOSymbol(const char* symbol) { |
static void* dl_handle = SystemLibMachOHandle(); |
if (!dl_handle) { |
- return NULL; |
+ return nullptr; |
} |
return dlsym(dl_handle, symbol); |
} |
@@ -37,22 +37,22 @@ namespace { |
// getsectiondata() and getsegmentdata() are not always present, but when they |
// are, they’re in the same library as getsectbyname(). If the library cannot |
-// be found or a handle to it cannot be returned, returns NULL. |
+// be found or a handle to it cannot be returned, returns nullptr. |
void* SystemLibMachOHandle() { |
Dl_info info; |
@@ -37,22 +37,22 @@ namespace { |
} |
// Returns a function pointer to a function in libmacho based on a lookup of |
-// that function by symbol name. Returns NULL if libmacho cannot be found or |
+// that function by symbol name. Returns nullptr if libmacho cannot be found or |
// opened, or if the named symbol cannot be found in libmacho. |
void* LookUpSystemLibMachOSymbol(const char* symbol) { |